@@ -14,9 +14,10 @@ except ImportError:
     print("Matplotlib package is not available !")
     sys.exit(-1)
 
-from satis import (remove_average, get_clean_fft, define_good_time_array, get_clean_average, get_coeff_fourier,
+from satis.satis_library import (remove_average, get_clean_fft, define_good_time_array, get_clean_average, get_coeff_fourier,
                        get_cumulative_average, compute_cumulative_fourier, get_psd_harmonics,
-                       apply_butter_bandpass_filter, avbp2global_compute_ftf, interpolate_signals)
+                       apply_butter_bandpass_filter, interpolate_signals)
+from satis import avbp2global_compute_ftf
 
 __all__ = ["step1_diagnostic", "step2_diagnostic", "step3_diagnostic", "step4_diagnostic"]
 
