@@ -19,12 +19,13 @@ def add_credits(figure):
     figure.subplots_adjust(bottom=0.5)
 
     # Add Logo
-    logo_ax = figure.add_axes([0.8, 0.01, 0.18, 0.18], anchor='SE', zorder=-1)
-    logo_ax.imshow(LOGO, interpolation='bicubic', alpha=ALPHA_VAL)
-    logo_ax.axis('off')
+    #logo_ax = figure.add_axes([0.8, 0.01, 0.18, 0.18], anchor='SE', zorder=-1)
+    #logo_ax.imshow(LOGO, interpolation='bicubic', alpha=ALPHA_VAL)
+    #logo_ax.axis('off')
 
     # Add Text
-    figure.text(0.79, 0.01, "Provided by CERFACS/COOP Team", fontsize=10, color='black', ha='right', va='bottom', alpha=ALPHA_VAL)
+    figure.text(0.79, 0.01, "Provided by CERFACS/COOP Team\nhttps://cerfacs.fr/coop/satis",
+                fontsize=10, color='black', ha='right', va='bottom', alpha=ALPHA_VAL)
 
     return figure
 
