@@ -1,8 +1,10 @@
 import click
-from satis import (display_header, read_signals, extract_subset, write_output, plot_time_signals,
+from satis.io import (read_signals, extract_subset, write_output, plot_time_signals,
 					   plot_fourier_convergence, plot_psd_convergence, plot_fourier_variability, plot_psd_variability)
+from satis.avbp2global import display_header
 import os
 import pkg_resources
+import matplotlib.pyplot as plt
 
 
 @click.group()
@@ -81,13 +83,15 @@ def time(filename, target_frequency, discardphase, dbspl, unit, transient_time,
 		unit,
 		dbspl)
 
-	plot_time_signals(
+	fig = plot_time_signals(
 		TIME,
 		SIGNALS,
 		target_frequency,
 		transient_time,
 		unit)
 
+	plt.show()
+
 main_cli.add_command(time)
 
 
@@ -157,13 +161,15 @@ def fourierconvergence(filename, target_frequency, discardphase, dbspl, unit, tr
 		unit,
 		dbspl)
 
-	plot_fourier_convergence(
+	fig = plot_fourier_convergence(
 		TIME,
 		SIGNALS,
 		target_frequency,
 		transient_time,
 		unit)
 
+	plt.show()
+
 main_cli.add_command(fourierconvergence)
 
 
@@ -233,7 +239,7 @@ def psdconvergence(filename, target_frequency, discardphase, dbspl, unit, transi
 		unit,
 		dbspl)
 
-	plot_psd_convergence(
+	fig = plot_psd_convergence(
 		TIME,
 		SIGNALS,
 		target_frequency,
@@ -244,6 +250,8 @@ def psdconvergence(filename, target_frequency, discardphase, dbspl, unit, transi
 		nb_blocks,
 		window_shape,
 		overlap)
+	
+	plt.show()
 
 main_cli.add_command(psdconvergence)
 
@@ -311,13 +319,15 @@ def fouriervariability(filename, target_frequency, discardphase, dbspl, unit, tr
 		unit,
 		dbspl)
 
-	plot_fourier_variability(
+	fig = plot_fourier_variability(
 		TIME,
 		SIGNALS,
 		target_frequency,
 		transient_time,
 		unit)
 
+	plt.show()
+
 main_cli.add_command(fouriervariability)
 
 
@@ -385,7 +395,7 @@ def psdvariability(filename, target_frequency, discardphase, dbspl, unit, transi
 		unit,
 		dbspl)
 
-	plot_psd_variability(
+	fig = plot_psd_variability(
 		TIME,
 		SIGNALS,
 		target_frequency,
@@ -394,6 +404,8 @@ def psdvariability(filename, target_frequency, discardphase, dbspl, unit, transi
 		window_shape,
 		overlap)
 
+	plt.show()
+
 main_cli.add_command(psdvariability)
 
 
