@@ -556,7 +556,7 @@ def compute_cumulative_fourier(time_array, signal_array, target_frequency,
 
 def get_psd_harmonics(time_array, signal_array,
                       target_frequency, transient_time=0.0,
-                      nb_blocks=1, window_func="flat", overlap=0.0):
+                      nb_blocks=1, window_shape="flat", overlap=0.0):
     """ 
     *Compute the PSD of signal fluctuations and sort out the
     contributions of target_frequency, first and second harmonic
@@ -581,11 +581,11 @@ def get_psd_harmonics(time_array, signal_array,
     """
 
     # Extract fluctuations
-    signal = remove_average(signal)
+    signal_array = remove_average(signal_array)
 
     # Obtain the PSD:
     psd_spectrum, psd_frequencies, index_target = get_clean_psd(
-        time, signal, target_frequency, transient_time,
+        time_array, signal_array, target_frequency, transient_time,
         nb_blocks, window_shape, overlap
     )
 
